@@ -15,7 +15,7 @@ use std::{
 use bitflags::bitflags;
 use vtflib_sys as ffi;
 
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
 #[non_exhaustive]
 pub enum Error {
     /// Image is not loaded or only the header was loaded.
@@ -304,7 +304,7 @@ impl VtfLib {
 
 impl Drop for VtfLib {
     fn drop(&mut self) {
-        uninit_decrement()
+        uninit_decrement();
     }
 }
 
@@ -316,7 +316,7 @@ pub struct VtfGuard(PhantomData<*const ()>);
 
 impl Drop for VtfGuard {
     fn drop(&mut self) {
-        uninit_decrement()
+        uninit_decrement();
     }
 }
 
